@@ -96,7 +96,7 @@ class PluginManager(object):
 
 	def __init__(self, 
 				 categories_filter={"Default":IPlugin}, 
-				 directories_list=[os.path.dirname(__file__)], 
+				 directories_list=None, 
 				 plugin_info_ext="yapsy-plugin"):
 		"""
 		Initialize the mapping of the categories and set the list of
@@ -153,6 +153,8 @@ class PluginManager(object):
 		"""
 		Set the list of directories where to look for plugin places.
 		"""
+		if directories_list is None:
+			[os.path.dirname(__file__)]
 		self.plugins_places = directories_list
 
 	def setPluginInfoExtension(self,plugin_info_ext):
@@ -313,16 +315,24 @@ class PluginManager(object):
 		self.locatePlugins()
 		self.loadPlugins()
 
+
+	def getPluginByName(self,category,name):
+		"""
+		Get the plugin correspoding to a given category and name
+		"""
+		if self.category_mapping.has_key(category):
+			for item in self.category_mapping[category]:
+				if item.name == name:
+					return item
+		return None
+
 	def activatePluginByName(self,category,name):
 		"""
 		Activate a plugin corresponding to a given category + name.
 		"""
-		if self.category_mapping.has_key(category):
-			plugin_to_activate = None
-			for item in self.category_mapping[category]:
-				if item.name == name:
-					plugin_to_activate = item.plugin_object
-					break
+		pta_item = self.getPluginByName(category,name)
+		if pta_item is not None:
+			plugin_to_activate = pta_item.plugin_object
 			if plugin_to_activate is not None:
 				logging.debug("Activating plugin: %s.%s"% (category,name))
 				plugin_to_activate.activate()
